==> epathmap-1.8.2-sources.jar: com/shitu/epathmap/model/bean/Configs.java <==
package com.shitu.epathmap.model.bean;

import java.util.List;

public class Configs {

    /**
     * api : {"tts":{"name":"aws","keys":["us-east-2:bb3c1bd5-8b72-41bb-9186-7ba62cbed579","us-east-2"]}}
     */

    private ApiBean api;
    private Function function;

    public Function getFunction() {
        return function;
    }

    public void setFunction(Function function) {
        this.function = function;
    }

    public ApiBean getApi() {
        return api;
    }

    public void setApi(ApiBean api) {
        this.api = api;
    }

    public static class ApiBean {
        /**
         * tts : {"name":"aws","keys":["us-east-2:bb3c1bd5-8b72-41bb-9186-7ba62cbed579","us-east-2"]}
         */

        private TtsBean tts;

        public TtsBean getTts() {
            return tts;
        }

        public void setTts(TtsBean tts) {
            this.tts = tts;
        }

        public static class TtsBean {
            /**
             * name : aws
             * keys : ["us-east-2:bb3c1bd5-8b72-41bb-9186-7ba62cbed579","us-east-2"]
             */

            private String name;
            private List<String> keys;

            public String getName() {
                return name;
            }

            public void setName(String name) {
                this.name = name;
            }

            public List<String> getKeys() {
                return keys;
            }

            public void setKeys(List<String> keys) {
                this.keys = keys;
            }
        }
    }

    public static class Function{
        public boolean noDisplayNavFinishDialg;

        public boolean isShowNavFinishDialg() {
            return !noDisplayNavFinishDialg;
        }

        public void setShowNavFinishDialg(boolean showNavFinishDialg) {
            this.noDisplayNavFinishDialg = !showNavFinishDialg;
        }
    }


}

==> epathmap-1.9.0-sources.jar: com/shitu/epathmap/model/bean/Configs.java <==
package com.shitu.epathmap.model.bean;

import java.util.List;

public class Configs {

    /**
     * api : {"tts":{"name":"aws","keys":["us-east-2:bb3c1bd5-8b72-41bb-9186-7ba62cbed579","us-east-2"]}}
     */

    private ApiBean api;
    private Function function;

    public Function getFunction() {
        return function;
    }

    public void setFunction(Function function) {
        this.function = function;
    }

    public ApiBean getApi() {
        return api;
    }

    public void setApi(ApiBean api) {
        this.api = api;
    }

    public static class ApiBean {
        /**
         * tts : {"name":"aws","keys":["us-east-2:bb3c1bd5-8b72-41bb-9186-7ba62cbed579","us-east-2"]}
         */

        private TtsBean tts;

        public TtsBean getTts() {
            return tts;
        }

        public void setTts(TtsBean tts) {
            this.tts = tts;
        }

        public static class TtsBean {
            /**
             * name : aws
             * keys : ["us-east-2:bb3c1bd5-8b72-41bb-9186-7ba62cbed579","us-east-2"]
             */

            private String name;
            private List<String> keys;

            public String getName() {
                return name;
            }

            public void setName(String name) {
                this.name = name;
            }

            public List<String> getKeys() {
                return keys;
            }

            public void setKeys(List<String> keys) {
                this.keys = keys;
            }
        }
    }

    public static class Function{
        public boolean noDisplayNavFinishDialg;
        public boolean noRealTimeShare;

        public boolean isShowNavFinishDialg() {
            return !noDisplayNavFinishDialg;
        }

        public void setShowNavFinishDialg(boolean showNavFinishDialg) {
            this.noDisplayNavFinishDialg = !showNavFinishDialg;
        }

        public boolean isNoRealTimeShare() {
            return noRealTimeShare;
        }

        public void setNoRealTimeShare(boolean noRealTimeShare) {
            this.noRealTimeShare = noRealTimeShare;
        }
    }


}
